@@ -1,3 +1,3 @@
-from .git_regex_search import git_regex_search
+from .git_regex_search import Search
 from .git_regex_search import search_repo
 from .git_regex_search import process_env
\ No newline at end of file
